/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-debug.c                                                     *
 *                                                                         * 
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : print FILEINFO structure                                 *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * Functions    : MdcPrintFI()       - Display FILEINFO struct             *
 *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-debug.c,v 1.27 2003/06/10 22:55:38 enlf Exp $
 */

/*
   Copyright (C) 1997-2003 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

/****************************************************************************
                              H E A D E R S
****************************************************************************/

#include "medcon.h"


/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void MdcPrintFI(FILEINFO *fi)
{ 
  Uint32 i, j;
  int v;
  IMG_DATA *id;

  MdcPrntScrn("\n");
  MdcPrintLine('#',MDC_FULL_LENGTH);
  MdcPrntScrn("FILEINFO - Global Data\n");
  MdcPrintLine('#',MDC_FULL_LENGTH);
  MdcPrntScrn("FILE *ifp          : ");
  if (fi->ifp == NULL) MdcPrntScrn("<null>\n");
  else MdcPrntScrn("%p\n",fi->ifp);
  MdcPrntScrn("FILE *ofp          : ");
  if (fi->ofp == NULL) MdcPrntScrn("<null>\n");
  else MdcPrntScrn("%p\n",fi->ofp);
  MdcPrntScrn("ipath              : %s\n",fi->ipath);
  MdcPrntScrn("opath              : %s\n",fi->opath);
  if (fi->idir == NULL) 
  MdcPrntScrn("idir               : <null>\n");
  else
  MdcPrntScrn("idir               : %s\n",fi->idir);
  if (fi->odir == NULL)
  MdcPrntScrn("odir               : <null>\n");
  else
  MdcPrntScrn("odir               : %s\n",fi->odir);
  MdcPrntScrn("ifname             : %s\n",fi->ifname);
  MdcPrntScrn("ofname             : %s\n",fi->ofname);
  MdcPrntScrn("format             : %d (= %s)\n",fi->format
                                                   ,FrmtString[fi->format]);
  v = (int)fi->rawconv;
  MdcPrntScrn("rawconv            : %d (= %s)\n",v,MdcGetStrRawConv(v));
  v = (int)fi->endian;
  MdcPrntScrn("endian             : %d (= %s)\n",v,MdcGetStrEndian(v));
  v = (int)fi->compression;
  MdcPrntScrn("compression        : %d (= %s)\n",v,MdcGetStrCompression(v));
  MdcPrntScrn("truncated          : %d ",fi->truncated);
  MdcPrintYesNo(fi->truncated);
  MdcPrntScrn("diff_type          : %d ",fi->diff_type);
  MdcPrintYesNo(fi->diff_type);
  MdcPrntScrn("diff_size          : %d ",fi->diff_size);
  MdcPrintYesNo(fi->diff_size);
  MdcPrntScrn("number             : %u\n",fi->number);
  MdcPrntScrn("mwidth             : %u\n",fi->mwidth);
  MdcPrntScrn("mheight            : %u\n",fi->mheight);
  MdcPrntScrn("bits               : %hu\n",fi->bits);
  v = (int)fi->type;
  MdcPrntScrn("type               : %d (= %s)\n",v,MdcGetStrPixelType(v));
  MdcPrntScrn("dim[0]             : %-5hd (= total in use)\n",fi->dim[0]);
  MdcPrntScrn("dim[1]             : %-5hd (= pixels X-dim)\n",fi->dim[1]);
  MdcPrntScrn("dim[2]             : %-5hd (= pixels Y-dim)\n",fi->dim[2]);
  MdcPrntScrn("dim[3]             : %-5hd (= planes | (time) slices)\n"
                                                                ,fi->dim[3]);
  MdcPrntScrn("dim[4]             : %-5hd (= frames | time slots | phases)\n"
                                                                ,fi->dim[4]);
  MdcPrntScrn("dim[5]             : %-5hd (= gates  | R-R intervals)\n"
                                                                ,fi->dim[5]);
  MdcPrntScrn("dim[6]             : %-5hd (= beds   | detector heads)\n"
                                                                ,fi->dim[6]);
  MdcPrntScrn("dim[7]             : %-5hd (= ...    | energy windows)\n"
                                                                ,fi->dim[7]);
  MdcPrntScrn("pixdim[0]          : %+e\n",fi->pixdim[0]);
  MdcPrntScrn("pixdim[1]          : %+e [mm]\n",fi->pixdim[1]);
  MdcPrntScrn("pixdim[2]          : %+e [mm]\n",fi->pixdim[2]);
  MdcPrntScrn("pixdim[3]          : %+e [mm]\n",fi->pixdim[3]);
  for (i=4; i<MDC_MAX_DIMS; i++)
  MdcPrntScrn("pixdim[%u]          : %+e\n",i,fi->pixdim[i]);
  MdcPrntScrn("glmin              : %+e\n",fi->glmin);
  MdcPrntScrn("glmax              : %+e\n",fi->glmax);
  MdcPrntScrn("qglmin             : %+e\n",fi->qglmin);
  MdcPrntScrn("qglmax             : %+e\n",fi->qglmax);
  MdcPrntScrn("slice_projection   : %d (= %s)\n",fi->slice_projection,
                               MdcGetStrSlProjection(fi->slice_projection));
  MdcPrntScrn("pat_slice_orient   : %d (= %s)\n",fi->pat_slice_orient,
                               MdcGetStrPatSlOrient(fi->pat_slice_orient));
  MdcPrntScrn("pat_pos            : %s\n",fi->pat_pos);
  MdcPrntScrn("pat_orient         : %s\n",fi->pat_orient);
  MdcPrntScrn("patient_sex        : %s\n",fi->patient_sex);
  MdcPrntScrn("patient_name       : %s\n",fi->patient_name);
  MdcPrntScrn("patient_id         : %s\n",fi->patient_id);
  MdcPrntScrn("patient_dob        : %s\n",fi->patient_dob);
  MdcPrntScrn("patient_weight     : %.2f [kg]\n",fi->patient_weight);
  MdcPrntScrn("study_descr        : %s\n",fi->study_descr);
  MdcPrntScrn("study_id           : %s\n",fi->study_id);
  MdcPrntScrn("study_date_day     : %d\n",fi->study_date_day);
  MdcPrntScrn("study_date_month   : %d\n",fi->study_date_month);
  MdcPrntScrn("study_date_year    : %d\n",fi->study_date_year);
  MdcPrntScrn("study_time_hour    : %d\n",fi->study_time_hour);
  MdcPrntScrn("study_time_minute  : %d\n",fi->study_time_minute);
  MdcPrntScrn("study_time_second  : %d\n",fi->study_time_second);
  MdcPrntScrn("nr_series          : %-5hd ",fi->nr_series);
  if (fi->nr_series < 0) MdcPrintYesNo(MDC_NO);
  else MdcPrintYesNo(MDC_YES);
  MdcPrntScrn("nr_acquisition     : %-5hd ",fi->nr_acquisition);
  if (fi->nr_acquisition < 0) MdcPrintYesNo(MDC_NO);
  else MdcPrintYesNo(MDC_YES);
  MdcPrntScrn("nr_instance        : %-5hd ",fi->nr_instance);
  if (fi->nr_instance < 0) MdcPrintYesNo(MDC_NO);
  else MdcPrintYesNo(MDC_YES);
  MdcPrntScrn("decay_corrected    : %d ",fi->decay_corrected);
  MdcPrintYesNo(fi->decay_corrected);
  MdcPrntScrn("flood_corrected    : %d ",fi->flood_corrected);
  MdcPrintYesNo(fi->flood_corrected);
  v = fi->acquisition_type;
  MdcPrntScrn("acquisition_type   : %d (= %s)\n",v,MdcGetStrAcquisition(v));
  MdcPrntScrn("reconstructed      : %d ",fi->reconstructed);
  MdcPrintYesNo(fi->reconstructed);
  MdcPrntScrn("recon_method       : %s\n",fi->recon_method);
  MdcPrntScrn("series_descr       : %s\n",fi->series_descr);
  MdcPrntScrn("radiopharma        : %s\n",fi->radiopharma);
  MdcPrntScrn("filter_type        : %s\n",fi->filter_type);
  MdcPrntScrn("organ_code         : %s\n",fi->organ_code);
  MdcPrntScrn("isotope_code       : %s\n",fi->isotope_code);
  MdcPrntScrn("isotope_halflife   : %+e [sec]\n",fi->isotope_halflife);
  MdcPrntScrn("injected_dose      : %+e [MBq]\n",fi->injected_dose);
  MdcPrntScrn("gantry_tilt        : %+e [degrees]\n",fi->gantry_tilt);
  v = (int) fi->map;
  MdcPrntScrn("map                : %u (= %s)\n",v,MdcGetStrColorMap(v));
  MdcPrntScrn("comm_length        : %u\n",fi->comm_length);
  MdcPrntScrn("comment            : ");
  if ((fi->comment != NULL) && (fi->comm_length != 0)) {
    for (i=0; i<fi->comm_length; i++) MdcPrntScrn("%c",fi->comment[i]);
  }else{
    MdcPrntScrn("<null>");
  }
  MdcPrntScrn("\n");

  /* GATED DATA */
  MdcPrntScrn("\ngatednr            : %u\n",fi->gatednr);
  if (fi->gdata != NULL) {
    for (i=0; i < fi->gatednr; i++) {
       GATED_DATA *gd = &fi->gdata[i];

       MdcPrntScrn("\n");
       MdcPrintLine('-',MDC_FULL_LENGTH);
       MdcPrntScrn("FILEINFO - Gated (SPECT) Data #%.3u\n",i+1);
       MdcPrintLine('-',MDC_FULL_LENGTH);
       MdcPrntScrn("gspect_nesting     : %d (= %s)\n",gd->gspect_nesting
              ,MdcGetStrGSpectNesting(gd->gspect_nesting));
       MdcPrntScrn("nr_projections     : %g\n",gd->nr_projections);
       MdcPrntScrn("extent_rotation    : %g\n",gd->extent_rotation);
       MdcPrntScrn("study_duration     : %+e [ms]\n",gd->study_duration);
       MdcPrntScrn("image_duration     : %+e [ms]\n",gd->image_duration);
       MdcPrntScrn("time_per_proj      : %+e [ms]\n",gd->time_per_proj);
       MdcPrntScrn("window_low         : %+e [ms]\n",gd->window_low);
       MdcPrntScrn("window_high        : %+e [ms]\n",gd->window_high);
       MdcPrntScrn("cycles_observed    : %+e\n",gd->cycles_observed);
       MdcPrntScrn("cycles_acquired    : %+e\n\n",gd->cycles_acquired);
       MdcPrntScrn("heart rate (observed): %d [bpm] (observed)\n"
                        ,(int)MdcGetHeartRate(gd,MDC_HEART_RATE_OBSERVED));
       MdcPrntScrn("heart rate (acquired): %d [bpm] (acquired)\n"
                        ,(int)MdcGetHeartRate(gd,MDC_HEART_RATE_ACQUIRED));
    }
  }else{
    MdcPrntScrn("gdata              : <null>\n");
  }
  /* ACQUISITION DATA */
  MdcPrntScrn("\nacqnr              : %u\n",fi->acqnr);
  if (fi->acqdata != NULL) {
    for (i=0; i < fi->acqnr; i++) {
       ACQ_DATA *acq = &fi->acqdata[i];

       MdcPrntScrn("\n");
       MdcPrintLine('-',MDC_FULL_LENGTH);
       MdcPrntScrn("FILEINFO - Acquisition Data #%.3u\n",i+1);
       MdcPrintLine('-',MDC_FULL_LENGTH);
       v = acq->rotation_direction;
       MdcPrntScrn("rotation_direction : %d (= %s)\n",v,MdcGetStrRotation(v));
       v = acq->detector_motion;
       MdcPrntScrn("detector_motion    : %d (= %s)\n",v,MdcGetStrMotion(v));
       MdcPrntScrn("rotation_offset    : %g [mm]\n",acq->rotation_offset);
       MdcPrntScrn("radial_position    : %g [mm]\n",acq->radial_position);
       MdcPrntScrn("angle_start        : %g [degrees]\n",acq->angle_start);
       MdcPrntScrn("angle_step         : %g [degrees]\n",acq->angle_step);
       MdcPrntScrn("scan_arc           : %g [degrees]\n",acq->scan_arc);
    }
  }else{
    MdcPrntScrn("acqdata            : <null>\n");
  }

  /* IMAGE DATA */
  for (i=0; i<fi->number; i++) {
     id = &fi->image[i];
     MdcPrntScrn("\n");
     MdcPrintLine('-',MDC_FULL_LENGTH);
     MdcPrntScrn("FILEINFO - Image Data #%.3u\n",i+1);  
     MdcPrintLine('-',MDC_FULL_LENGTH);
     MdcPrntScrn("width              : %u\n",id->width);
     MdcPrntScrn("height             : %u\n",id->height);
     MdcPrntScrn("bits               : %hd\n",id->bits);
     MdcPrntScrn("type               : %hd (= %s)\n",id->type
                                             ,MdcGetStrPixelType(id->type));
     MdcPrntScrn("flags              : 0x%x\n",id->flags);
     MdcPrntScrn("min                : %+e\n",id->min);
     MdcPrntScrn("max                : %+e\n",id->max);
     MdcPrntScrn("qmin               : %+e\n",id->qmin);
     MdcPrntScrn("qmax               : %+e\n",id->qmax);
     MdcPrntScrn("fmin               : %+e\n",id->fmin);
     MdcPrntScrn("fmax               : %+e\n",id->fmax);
     MdcPrntScrn("qfmin              : %+e\n",id->qfmin);
     MdcPrntScrn("qfmax              : %+e\n",id->qfmax);
     MdcPrntScrn("rescale_slope      : %+e\n",id->rescale_slope);
     MdcPrntScrn("rescale_intercept  : %+e\n",id->rescale_intercept);
     MdcPrntScrn("rescaled           : %d ",id->rescaled);
     MdcPrintYesNo(id->rescaled);
     MdcPrntScrn("rescaled_min       : %+e\n",id->rescaled_min);
     MdcPrntScrn("rescaled_max       : %+e\n",id->rescaled_max);
     MdcPrntScrn("rescaled_fctr      : %+e\n",id->rescaled_fctr);
     MdcPrntScrn("rescaled_slope     : %+e\n",id->rescaled_slope);
     MdcPrntScrn("rescaled_intercept : %+e\n",id->rescaled_intercept);
     MdcPrntScrn("buf                : %p\n",id->buf);
     MdcPrntScrn("quant_units        : %hd\n",id->quant_units);
     MdcPrntScrn("calibr_units       : %hd\n",id->calibr_units);
     MdcPrntScrn("quant_scale        : %+e\n",id->quant_scale);
     MdcPrntScrn("calibr_fctr        : %+e\n",id->calibr_fctr);
     MdcPrntScrn("pixel_xsize        : %+e [mm]\n",id->pixel_xsize);
     MdcPrntScrn("pixel_ysize        : %+e [mm]\n",id->pixel_ysize);
     MdcPrntScrn("slice_width        : %+e [mm]\n",id->slice_width);
     MdcPrntScrn("frame_start        : %+e [ms]\n",id->frame_start);
     MdcPrntScrn("frame_duration     : %+e [ms]\n",id->frame_duration);
     MdcPrntScrn("recon_scale        : %+e\n",id->recon_scale);
     MdcPrntScrn("image_mod          : %s\n",id->image_mod);
     for (j=0; j<3; j++) MdcPrntScrn("image_pos_dev[%u]   : %+e [mm]\n",j
                                                      ,id->image_pos_dev[j]);
     for (j=0; j<3; j++) MdcPrntScrn("image_pos_pat[%u]   : %+e [mm]\n",j
                                                      ,id->image_pos_pat[j]);
     for (j=0; j<6; j++) MdcPrntScrn("image_orient_dev[%u]: %+e [mm]\n",j
                                                      ,id->image_orient_dev[j]);
     for (j=0; j<6; j++) MdcPrntScrn("image_orient_pat[%u]: %+e [mm]\n",j
                                                      ,id->image_orient_pat[j]);
     MdcPrntScrn("slice_spacing      : %+e [mm]\n",id->slice_spacing);
     MdcPrntScrn("ct_zoom_fctr       : %+e\n",id->ct_zoom_fctr);

     if (id->sdata != NULL) {
       STATIC_DATA *sd = id->sdata;
       MdcPrntScrn("\n");
       MdcPrintLine('-',MDC_HALF_LENGTH);
       MdcPrntScrn("FILEINFO - Static Data #%.3u\n",i+1);
       MdcPrintLine('-',MDC_HALF_LENGTH);
       MdcPrntScrn("label              : %s\n",sd->label);
       MdcPrntScrn("total_counts       : %g\n",sd->total_counts);
       MdcPrntScrn("image_duration     : %+e (ms)\n",sd->image_duration);
       MdcPrntScrn("start_time_hour    : %02hd\n",sd->start_time_hour);
       MdcPrntScrn("start_time_minute  : %02hd\n",sd->start_time_minute);
       MdcPrntScrn("start_time_second  : %02hd\n",sd->start_time_second);
       MdcPrintLine('-',MDC_HALF_LENGTH);
     }
 }

}


void MdcDebugPrint(char *fmt, ...)
{
  va_list args;

  if (MDC_MY_DEBUG) {
    va_start(args,fmt);
    vsprintf(mdcbufr, fmt, args);
    fprintf(stdout,"%s",mdcbufr);
    va_end(args);
    fflush(stdout);
  }

}

